import { IEntity, IFromDateFromTimeEntity, IToDateToTimeEntity, IKeyValue, IFromDateToDateEntity } from '../../definitions.interface';
import { IApiEntity, IDateTimeEntity, IFromDateFromTimeToDateToTimeEntity } from '../../entities-definitions.interface';
export declare class DateTimeFieldHelper {
    private dc;
    /**
     * @stable [25.08.2018]
     * @param {TEntity} changes
     * @param {(entity: TEntity) => string} fromDateResolver
     * @param {(entity: TEntity) => string} toDateResolver
     * @param {number} monthAgo
     * @returns {IFromDateToDateEntity}
     */
    buildLastPeriodFromChanges<TEntity extends IEntity>(changes: TEntity, fromDateResolver: (entity: TEntity) => string, toDateResolver: (entity: TEntity) => string, monthAgo?: number): IFromDateToDateEntity;
    /**
     * @stable [25.08.2018]
     * @param {IApiEntity<TEntity extends IEntity>} apiEntity
     * @param {(entity: TEntity) => string} fromDateResolver
     * @param {(entity: TEntity) => string} toDateResolver
     * @param {number} monthAgo
     * @returns {IFromDateToDateEntity}
     */
    buildLastPeriod<TEntity extends IEntity>(apiEntity: IApiEntity<TEntity>, fromDateResolver: (entity: TEntity) => string, toDateResolver: (entity: TEntity) => string, monthAgo?: number): IFromDateToDateEntity;
    buildLastDateTimePeriod<TEntity extends IEntity>(apiEntity: IApiEntity<TEntity>, fromDateResolver: (entity: TEntity) => string, toDateResolver: (entity: TEntity) => string, monthAgo?: number): IFromDateFromTimeToDateToTimeEntity;
    buildLastDateTimePeriodFromChanges<TEntity extends IEntity>(changes: TEntity, fromDateResolver: (entity: TEntity) => string, toDateResolver: (entity: TEntity) => string, monthAgo?: number): IFromDateToDateEntity;
    buildDateTimeFromField<TEntity extends IDateTimeEntity>(apiEntity: IApiEntity<TEntity>, returnOriginalValueIfNoChanges?: boolean): string;
    buildDateTimeSinceField<TEntity extends IFromDateFromTimeEntity>(apiEntity: IApiEntity<TEntity>, returnOriginalValueIfNoChanges?: boolean): string;
    buildDateTimeTillField<TEntity extends IToDateToTimeEntity>(apiEntity: IApiEntity<TEntity>, returnOriginalValueIfNoChanges?: boolean): string;
    joinDateTimeFields<TEntity extends IFromDateFromTimeToDateToTimeEntity>(apiEntity: IApiEntity<TEntity>, returnOriginalValueIfNoChanges?: boolean): IFromDateFromTimeToDateToTimeEntity;
    composeDateTimeSinceField<TEntity extends IFromDateFromTimeEntity>(apiEntity: IApiEntity<TEntity>, returnOriginalValueIfNoChanges?: boolean): IFromDateFromTimeEntity;
    composeDateTimeTillField<TEntity extends IToDateToTimeEntity>(apiEntity: IApiEntity<TEntity>, returnOriginalValueIfNoChanges?: boolean): IToDateToTimeEntity;
    /**
     * @stable [02.06.2018]
     * @param {TEntity} entity
     * @param {Date} defaultFromDate
     * @param {Date} defaultToDate
     * @returns {IFromDateToDateEntity}
     */
    composeDateTimeRangeFields<TEntity extends IFromDateFromTimeToDateToTimeEntity>(entity: TEntity, defaultFromDate?: Date, defaultToDate?: Date): IFromDateToDateEntity;
    buildDateTimeRangeFields<TEntity extends IEntity>(entity: TEntity, fromDateResolver: (entity: TEntity) => string, toDateResolver: (entity: TEntity) => string, fromTimeResolver: (entity: TEntity) => string, toTimeResolver: (entity: TEntity) => string, fromDateFieldName: string, toDateFieldName: string, defaultFromDate: Date, defaultToDate: Date): TEntity;
    splitToDateTimeRangeFields(entity: IFromDateFromTimeToDateToTimeEntity): IFromDateFromTimeToDateToTimeEntity;
    splitToDateTimeSinceFields(entity: IFromDateFromTimeEntity): IFromDateFromTimeEntity;
    splitToDateTimeTillFields(entity: IToDateToTimeEntity): IToDateToTimeEntity;
    splitToDateTimeBasicFields(entity: IDateTimeEntity): IDateTimeEntity;
    splitToDateAndTimeBasicFields<TEntity>(entity: IDateTimeEntity, dateResolver: (entity: TEntity) => string): IDateTimeEntity;
    /**
     * @deprecated
     */
    splitToDateTimeFields<TEntity>(entity: TEntity, dateFieldName: string, timeFieldName: string, dateResolver: (entity: TEntity) => string): IKeyValue;
    toDateTime<TEntity extends IEntity>(apiEntity: IApiEntity<TEntity>, dateResolver: (entity: TEntity) => string, timeResolver?: (entity: TEntity) => string, returnOriginalValueIfNoChanges?: boolean, defaultTime?: string): string;
}
