"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var util_1 = require("../../../../util");
var DelayedChangesFieldPlugin = /** @class */ (function () {
    /**
     * @stable [18.05.2018]
     * @param {IUniversalField} component
     */
    function DelayedChangesFieldPlugin(component) {
        this.component = component;
        this.delayedTask = new util_1.DelayedTask(this.doDelay.bind(this), this.props.delayTimeout || DelayedChangesFieldPlugin.DEFAULT_DELAY_TIMEOUT);
        this.component.onChange = util_1.sequence(this.component.onChange, this.onChange, this);
        this.component.onChangeManually = util_1.sequence(this.component.onChangeManually, this.onChangeManually, this);
        this.component.onKeyEnter = util_1.sequence(this.component.onKeyEnter, this.onKeyEnter, this);
    }
    /**
     * @stable [04.05.2018]
     */
    DelayedChangesFieldPlugin.prototype.componentWillUnmount = function () {
        this.delayedTask.stop();
    };
    /**
     * @stable [04.05.2018]
     * @param {IKeyboardEvent} event
     */
    DelayedChangesFieldPlugin.prototype.onKeyEnter = function (event) {
        util_1.cancelEvent(event);
        this.delayedTask.stop();
        this.doDelay(this.currentValue);
    };
    /**
     * @stable [04.05.2018]
     * @param {IChangeEvent} event
     */
    DelayedChangesFieldPlugin.prototype.onChange = function (event) {
        this.onChangeManually(event.target.value);
    };
    /**
     * @stable [18.05.2018]
     */
    DelayedChangesFieldPlugin.prototype.onChangeManually = function (value) {
        this.currentValue = value;
        this.delayedTask.start();
    };
    /**
     * @stable [04.05.2018]
     * @param {AnyT} value
     */
    DelayedChangesFieldPlugin.prototype.doDelay = function (value) {
        if (this.props.onDelay) {
            this.props.onDelay(value);
        }
    };
    Object.defineProperty(DelayedChangesFieldPlugin.prototype, "props", {
        /**
         * @stable [04.05.2018]
         * @returns {IDelayedChangesFieldPluginConfiguration}
         */
        get: function () {
            return this.component.props;
        },
        enumerable: true,
        configurable: true
    });
    DelayedChangesFieldPlugin.DEFAULT_DELAY_TIMEOUT = 1500;
    return DelayedChangesFieldPlugin;
}());
exports.DelayedChangesFieldPlugin = DelayedChangesFieldPlugin;
//# sourceMappingURL=delayed-changes-field.plugin.js.map